Changeset: d5da9a779b6f for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=d5da9a779b6f
Modified Files:
        debian/fix-deb.sh
Branch: Jun2016
Log Message:

Older Ubuntu (and presumably Debian) have php5-cli and no php5-sockets.


diffs (15 lines):

diff --git a/debian/fix-deb.sh b/debian/fix-deb.sh
--- a/debian/fix-deb.sh
+++ b/debian/fix-deb.sh
@@ -48,8 +48,8 @@ esac
 
 case $SUITE in
 wheezy | jessie | precise | trusty | wily)
-    # Xenial Xerus (and presumably newer releases) uses php-common,
-    # all others still have php5-common
-    sed -i 's/php-common/php5-common/' debian/control
+    # Xenial Xerus (and presumably newer releases) uses php-cli,
+    # all others still have php5-cli and don't have php*-sockets
+    sed -i 's/php-cli/php5-cli/;s/, *php-sockets//' debian/control
     ;;
 esac
_______________________________________________
checkin-list mailing list
[email protected]
https://www.monetdb.org/mailman/listinfo/checkin-list

Reply via email to